( cd usr/lib64 ; rm -rf libhistory.so.5 )
( cd usr/lib64 ; ln -sf libhistory.so.5.1 libhistory.so.5 )
( cd usr/lib64 ; rm -rf libhistory.so )
( cd usr/lib64 ; ln -sf libhistory.so.5 libhistory.so )
( cd usr/lib64 ; rm -rf libreadline.so.5 )
( cd usr/lib64 ; ln -sf libreadline.so.5.1 libreadline.so.5 )
( cd usr/lib64 ; rm -rf libreadline.so )
( cd usr/lib64 ; ln -sf libreadline.so.5 libreadline.so )
